@@ -195,7 +195,7 @@ class AwesomeTable():
             col_order, col_strategy, col_search, col_searchby = st.columns([1,1,2,1])
             if self.show_order:
                 if self.order_by is not None and self.order_by in self.get_columns_with_dtype_string():
-                    col_order.selectbox('Order by', self.get_columns_with_dtype_string(), format_func=self.get_column_label_by_name, index=self.order_by, on_change=self.order_table(), key='order_column')
+                    col_order.selectbox('Order by', self.get_columns_with_dtype_string(), format_func=self.get_column_label_by_name, index=self.get_index_from_column_name, on_change=self.order_table(), key='order_column')
                 else:
                     col_order.selectbox('Order by', self.get_columns_with_dtype_string(), format_func=self.get_column_label_by_name, on_change=self.order_table(), key='order_column')
                 if  self.order_descending:  
